#!/bin/bash
# packager         : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# source location    : http://rlog.googlecode.com/files/rlog-1.4.tar.gz
# last revised       : 02.02.2008

softname='rlog'
softversion='1.4'
packageversion='54.1'

arch='i486'
cpu='i686'

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://rlog.googlecode.com/files/$softname-$softversion.tar.gz

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
     |-----handy-ruler------------------------------------------------------|
rlog: rlog (a C++ logging library)
rlog:
rlog: RLog provides a flexible message logging facility for C++ programs
rlog: and libraries. It is highly optimized for the case where no log
rlog: messages are output, so that it can be left in production code and
rlog: enabled on-demand.
rlog:
rlog:
rlog:
rlog:
rlog:

EOF

# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src

# build

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=/usr \
      --program-prefix="" \
      --program-suffix="" \
      --build=$arch-slackware-linux

    make
    make install DESTDIR=$dest

# add 'default' files
    cp -a \
      AUTHORS COPYING ChangeLog INSTALL README docs/html docs/latex/*.pdf \
      $dest/usr/doc/$softname-$softversion
      
    rm -rf $dest/usr/share
      
# Compress Man Pages
gzip -9 $dest/usr/man/man?/*

# Strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.tgz

# md5sum signature
cd $buildir
md5sum $package.tgz > $package.md5

# .dep
cd $buildir
echo -e "cxxlibs,gcc" > $package.dep

# generate source file
echo http://users.zenwalk.org/user-accounts/bip/ISO/l/rlog/source/build-rlog.sh > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
